num\_tini4 package
==================

Submodules
----------

num\_tini4.num module
---------------------

.. automodule:: num_tini4.num
   :members:
   :undoc-members:
   :show-inheritance:

num\_tini4.primes module
------------------------

.. automodule:: num_tini4.primes
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: num_tini4
   :members:
   :undoc-members:
   :show-inheritance:
